|
From: <fri...@us...> - 2008-12-30 11:04:27
|
Revision: 9655
http://zaf.svn.sourceforge.net/zaf/?rev=9655&view=rev
Author: friedelwolff
Date: 2008-12-30 11:04:17 +0000 (Tue, 30 Dec 2008)
Log Message:
-----------
Split negative_indicative into the _i and _anga cases to allow negative infinitives. +Negative infinitives (with and without object morphemes)
Modified Paths:
--------------
trunk/dict/zu/hunspell/zu_aff.py
Modified: trunk/dict/zu/hunspell/zu_aff.py
===================================================================
--- trunk/dict/zu/hunspell/zu_aff.py 2008-12-30 10:36:30 UTC (rev 9654)
+++ trunk/dict/zu/hunspell/zu_aff.py 2008-12-30 11:04:17 UTC (rev 9655)
@@ -368,10 +368,13 @@
past_indicative = aff.add_group(suffix=True, flag="d")
# This group contains the suffixes for the past indicative (positive)
- negative_indicative = aff.add_group(suffix=True, flag="e")
- # This groups contains the suffixes for the negative indicative (future and
- # present)
+ negative_i = aff.add_group(suffix=True, flag="e")
+ # This groups contains the suffixes for the negative indicative (present)
+ # and infinitive
+ negative_anga = aff.add_group(suffix=True, flag="f")
+ # This groups contains the suffixes for the negative indicative (past)
+
imperative = aff.add_group(suffix=True, flag="F")
# This contains suffixes for imperative mode
@@ -391,12 +394,12 @@
# Here we don't use verb_rules, because this will always combine with -ya-
simple_subjects.add_rule(affix=morpheme)
# Indicative, present, negative with subject morpheme only
- verb_rules(main_subjects, affix=add_semivowels("a"+morpheme), needaffix=True, circumfix=True, continuation_classes=[negative_indicative])
+ verb_rules(main_subjects, affix=add_semivowels("a"+morpheme), needaffix=True, circumfix=True, continuation_classes=[negative_i, negative_anga])
#Negative future tenses:
verb_rules(simple_subjects_neg, affix=(add_semivowels("a" + morpheme)))
# We handle class 1 negative separately:
- verb_rules(main_subjects, affix="aka", needaffix=True, circumfix=True, continuation_classes=[negative_indicative])
+ verb_rules(main_subjects, affix="aka", needaffix=True, circumfix=True, continuation_classes=[negative_i, negative_anga])
simple_subjects_neg.add_rule(affix=add_semivowels("aka"))
#indicative long form, present, positive
@@ -428,7 +431,8 @@
verb_rules(infixes, affix="uku", morphology="INFINITIVE", continuation_classes=[locative])
#infinitive + -sa- progressive aspectual morpheme
verb_rules(infixes, affix="ukusa", morphology="INFINITIVE_PROG", continuation_classes=[locative])
- #TODO: infinitive, negative
+ #infinitive, negative
+ verb_rules(infixes, affix="ukunga", needaffix=True, circumfix=True, morphology="INFINITIVE_NEG", continuation_classes=[negative_i])#XXX
for morpheme in object_morphemes:
#Although this makes sense, this causes rules from main_subjects with mandatory continuation classes to
@@ -466,6 +470,8 @@
#infinitive with object morpheme
verb_rules(infixes, affix="uku"+morpheme, morphology="INFINITIVE_with_OBJ", continuation_classes=[locative])
+ #negative infinitive with object morpheme
+ verb_rules(infixes, affix="ukunga"+morpheme, needaffix=True, circumfix=True, morphology="INFINITIVE_NEG_with_OBJ", continuation_classes=[negative_i])
#infinitive + -sa- progressive aspectual morpheme
verb_rules(infixes, affix="ukusa"+morpheme, morphology="INFINITIVE_PROG_with_OBJ", continuation_classes=[locative])
@@ -475,8 +481,8 @@
past_indicative.add_rule(affix="e", strip="a", morphology="RECENT_PAST_IND_SHORT")
past_indicative.add_rule(affix="ile", strip="a", morphology="RECENT_PAST_IND_LONG")
- negative_indicative.add_rule(affix="i", circumfix=True, strip="a", morphology="PRESENT_IND_NEGATIVE")
- negative_indicative.add_rule(affix="nga", circumfix=True, morphology="PAST_IND_NEGATIVE")
+ negative_i.add_rule(affix="i", circumfix=True, strip="a", morphology="PRESENT_IND_NEG/INFINITIVE_NEG")
+ negative_anga.add_rule(affix="nga", circumfix=True, morphology="PAST_IND_NEGATIVE")
imperative.add_rule(affix="ni", condition="a", morphology="IMPERATIVE_(PLURAL)")
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|